developerscripttools.SvnAddAllScript
====================================

.. abjad-lineage:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript

.. autoclass:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnAddAllScript.SvnAddAllScript.SvnAddAllScript.__repr__
   :noindex:
